@@ -1,6 +1,6 @@
 /***
 |''Name''|TiddlySpaceConfig|
-|''Version''|0.6.3|
+|''Version''|0.6.4|
 |''Description''|TiddlySpace configuration|
 |''Status''|stable|
 |''Source''|http://github.com/TiddlySpace/tiddlyspace/raw/master/src/plugins/TiddlySpaceConfig.js|
@@ -72,7 +72,7 @@ sssp.removeTiddlerCallback = function(context, userParams) {
 		var callback = function(context, userParams) {
 			if(context.status) {
 				var dirty = store.isDirty();
-				store.saveTiddler(context.tiddler);
+				store.saveTiddler(context.tiddler).clearChangeCount();
 				store.setDirty(dirty);
 			} else {
 				store.notify(title, true);
@@ -227,5 +227,17 @@ httpReq = function(type, url, callback, params, headers, data, contentType,
 // register style sheet for backstage separately (important)
 store.addNotification("StyleSheetBackstage", refreshStyles);
 
+config.paramifiers.follow = {
+	onstart: function(v) {
+		if(!readOnly) {
+			var bag = "%0_public".format([config.extensions.tiddlyspace.currentSpace.name]);
+			story.displayTiddler(null, v, DEFAULT_EDIT_TEMPLATE, null, null,
+				"server.bag:%0 server.workspace:bags/%0".format([bag]));
+			story.setTiddlerTag(v, "follow", 1);
+			story.focusTiddler(v, "text");
+		}
+	}
+};
+
 })(jQuery);
 //}}}
